# 图像术语

## 分辨率

分辨率，又称解析度、解像度，可以从显示分辨率与图像分辨率两个方向来分类。

- **显示分辨率**（屏幕分辨率）是屏幕图像的精密度，是指显示器所能显示的像素有多少。如常见电视厂家标注：4k 或者 8k
- **图像分辨率** 则是单位英寸中所包含的像素点数。比如，视频素材是 2k 还是 4k。

## 帧速率

**帧速率** 也称为 FPS（Frames PerSecond）的缩写——帧/秒。是指每秒钟刷新的图片的帧数，也可以理解为图形处理器每秒钟能够刷新几次。每秒钟帧数（FPS）越多，所显示的动作就会越流畅。捕捉动态视频内容时，此数字愈高愈好。

## 码流

码流（Data Rate）是指视频文件在单位时间内使用的数据流量，也叫码率或码流率，通俗一点的理解就是取样率，是视频编码中画面质量控制中最重要的部分，一般我们用的单位是 kb/s 或者 Mb/s。一般来说同样分辨率下，视频文件的码流越大，压缩比就越小，画面质量就越高。码流越大，说明单位时间内取样率越大，数据流，精度就越高，处理出来的文件就越接近原始文件，图像质量越好，画质越清晰，要求播放设备的解码能力也越高。

## 比特率

在电信和计算领域，比特率（英语：Bit rate，变量R[1]）是单位时间内传输送或处理的比特的数量。比特率经常在电信领域用作连接速度、传输速度、信息传输速率和数字带宽容量的同义词。

在数字多媒体领域，比特率是单位时间播放连续的媒体如压缩后的音频或视频的比特数量。在这个意义上讲，它相当于术语数字带宽消耗量，或吞吐量。

比特率越高，传送的数据越大，还原后的音质、画质就越好，在视频领域，比特率常翻译为码率 !!!
